Module git_pack::index::traverse

source ·
Modules

Structs

Traversal options for index::File::traverse().
The outcome of the traverse() method.
Statistics regarding object encountered during execution of the traverse() method.

Enums

The way we verify the pack
The progress ids used in traverse() .
The ways to validate decoded objects before passing them to the processor.